package shukan;
import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;


/**
 * Shukan planner application.
 */
public class Shukan
{
    /** Shukan window top margin */
    private final static int TOP_MARGIN = 30;
    /** Shukan window left margin */
    private final static int LEFT_MARGIN = 50;

    /**
     * Creates AWT Frame with Shukan tools
     */
    public static void main (String[] args)
    {
        // Jikan data base creation and set up
        ShukanData data = new ShukanData ();
        ShukanIO io = new ShukanIO (data);


        // Handling edition mode
        if (args.length > 0)
            if (args[0].equals ("edit"))
            {
                new ShukanTex (data);
                System.exit (0);
            }

        // Creating Shukan viewer
        JFrame frame = new JFrame ("SHUKAN 1.6");
        JPanel global = new JPanel(new BorderLayout());
        ShukanView canvas = new ShukanView (data, io);
        ShukanViewBar mytoolbar = new ShukanViewBar(90);

        // Getting the display size
        GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment ();
        GraphicsDevice gd = ge.getScreenDevices()[0];
        GraphicsConfiguration[] gc = gd.getConfigurations ();
        Rectangle gcBounds = gc[0].getBounds ();
        canvas.restrictSize ((int) (gcBounds.getWidth ()) - LEFT_MARGIN,
                (int) (gcBounds.getHeight ()) - TOP_MARGIN - mytoolbar.getHeight());
        mytoolbar.setSize(new Dimension((int) (gcBounds.getWidth ()) - LEFT_MARGIN, mytoolbar.getHeight()));

        // Adding a openGL input handler (controller)
        ShukanController myController = new ShukanController (canvas, mytoolbar, data);
        canvas.addKeyListener (myController);
        canvas.addMouseListener (myController);
        mytoolbar.addActionListener(myController);


        // Preparing the window closing button
        frame.addWindowListener (
                new WindowAdapter ()
                {
                    public void windowClosing (WindowEvent e)
                    {
//          Shukan.io.save ();
                        System.exit (0);
                    }
                });


        // Setting the window geometry
        global.add(mytoolbar, BorderLayout.NORTH);
        global.add (canvas, BorderLayout.CENTER);
        frame.add(global);
        Insets ins = frame.getInsets ();
        frame.setSize (canvas.displayWidth () + ins.left + ins.right,
                canvas.displayHeight ()+ mytoolbar.getHeight()+ ins.top + ins.bottom);
        frame.setLocation (LEFT_MARGIN, 0);
        frame.setBackground (Color.white);
        frame.setVisible (true);

        // Triggering input handler loop
        canvas.requestFocus ();
    }
}
